@@ -3,6 +3,7 @@ import os
 import time
 from typing import List, Literal, Optional
 
+import requests
 import simplejson as json
 
 from worker.data.api import API
@@ -53,7 +54,7 @@ class PartialRerunMerge:
             self.REMAINING_SECONDS_THRESHOLD = int(remaining_seconds_threshold)
 
         # the following attributes are set in the preprocess method
-        self.partial_rerun_id: Optional[int] = None
+        self.partial_well_rerun_id: Optional[int] = None
         self.app_id: Optional[int] = None
         self.original_asset_id: Optional[int] = None
         self.rerun_asset_id: Optional[int] = None
@@ -74,8 +75,14 @@ class PartialRerunMerge:
         :raises Exception: if an error occurs during the merge operation
         """
         self.preprocess(event)
-        self.merge_cache_state()
-        self.merge_collections()
+
+        try:
+            self.merge_cache_state()
+            self.merge_collections()
+        except Exception as ex:
+            self.logger.error(f"An error occurred during the merge operation: {ex}")
+            self.merging_progress.fail_status(str(ex))
+
         self.update_status()
 
     def preprocess(self, event: dict) -> None:
@@ -85,36 +92,45 @@ class PartialRerunMerge:
         # Add your preprocessing logic here
         event = event.get("data") or {}
 
-        self.partial_rerun_id = event.get("partial_rerun_id")
+        self.partial_well_rerun_id = event.get("partial_well_rerun_id")
         self.app_id = event.get("app_id")
         self.original_asset_id = event.get("asset_id")
         self.rerun_asset_id = event.get("rerun_asset_id")
-        self.start_timestamp = event.get("start")
-        self.end_timestamp = event.get("end")
 
         segment = event.get("source_type")
         if segment != "drilling":
             raise ValueError(f"Invalid source type: {segment}")
 
+        self.start_timestamp = event.get("start")
         start_wits = self.get_wits_at_or(self.rerun_asset_id, self.start_timestamp, "after")
-        end_wits = self.get_wits_at_or(self.rerun_asset_id, self.end_timestamp, "before")
+
+        if end := event.get("end"):
+            self.end_timestamp = end
+            end_wits = self.get_wits_at_or(self.rerun_asset_id, self.end_timestamp, "before")
+        else:
+            end_wits = self.get_wits_at_or(self.rerun_asset_id, self.MAX_TIMESTAMP, "before")
+            self.end_timestamp = end_wits.get("timestamp")
 
         self.start_hole_depth = start_wits.get("data").get("hole_depth")
         self.end_hole_depth = end_wits.get("data").get("hole_depth")
 
         self.rerun_mode = RerunMode(event.get("rerun_mode"))
 
-        self.merging_progress = MergingProgress(self.partial_rerun_id, self.app_id, self.api)
+        self.merging_progress = MergingProgress(self.partial_well_rerun_id, self.app_id, self.api)
 
     def merge_cache_state(self) -> None:
         """
         Handles the merging of cache state.
         """
-        if self.merging_progress.is_cache_update_completed:
-            return
+        try:
+            if self.merging_progress.is_cache_update_completed:
+                return
 
-        for module in self.schema.modules:
-            module.update_cache(merger=self)
+            for module in self.schema.modules:
+                module.update_cache(merger=self)
+        except Exception as ex:
+            error_message = f"Failed to update cache state: {ex}"
+            raise Exception(error_message)
 
     def merge_collections(self) -> None:
         """
@@ -123,24 +139,31 @@ class PartialRerunMerge:
         is_completed = True
 
         for collection in self.schema.collections:
-            if not self.has_time_to_continue_merging():
-                self.logger.debug("Not enough time to continue merging. Stopping.")
-                is_completed = False
-                break
-
             collection_name = collection.collection_name
-            if self.merging_progress.is_collection_completed(collection_name):
-                self.logger.debug(f"Collection {collection_name} is already completed or failed. Skipping.")
-                continue
+            self.logger.debug(f"Started merging collection: {collection_name}")
 
-            if collection.merging_method:
-                col_is_completed = getattr(self, collection.merging_method)(collection_name)
+            try:
+                if not self.has_time_to_continue_merging():
+                    self.logger.debug("Not enough time to continue merging. Stopping.")
+                    is_completed = False
+                    break
 
-            else:
-                col_is_completed = self.default_merging_method(collection_name)
+                if self.merging_progress.is_collection_completed(collection_name):
+                    self.logger.debug(f"Collection {collection_name} is already completed or failed. Skipping.")
+                    continue
 
-            if not col_is_completed:
-                is_completed = False
+                if collection.merging_method:
+                    col_is_completed = getattr(self, collection.merging_method)(collection_name)
+
+                else:
+                    col_is_completed = self.default_merging_method(collection_name)
+
+                if not col_is_completed:
+                    is_completed = False
+
+            except Exception as ex:
+                error_message = f"Failed to merge collection '{collection_name}': {ex}"
+                raise Exception(error_message)
 
         if is_completed:
             self.merging_progress.complete_status()
@@ -232,11 +255,11 @@ class PartialRerunMerge:
         self._post_data(collection_name, records)
         self.logger.debug(f"   --> {collection_name}, copied {len(records)} records")
 
-    def update_status(self):
+    def update_status(self) -> requests.Response:
         """
         Handles the updating of status. Update this method as per your requirements.
         """
-        self.merging_progress.update_status()
+        return self.merging_progress.update_status()
 
     def has_time_to_continue_merging(self, apply_half: Optional[bool] = False) -> bool:
         """
@@ -244,6 +267,9 @@ class PartialRerunMerge:
         :param apply_half: whether to apply half of the remaining seconds threshold
         :return: True if there is enough time, False otherwise
         """
+        if not self.lambda_context:
+            return True
+
         remaining_seconds = self.get_remaining_seconds()
         threshold = self.REMAINING_SECONDS_THRESHOLD_HALF if apply_half else self.REMAINING_SECONDS_THRESHOLD
         return remaining_seconds > threshold
