@@ -5,6 +5,7 @@ from dataclasses import asdict, dataclass
 from typing import List, Optional
 
 import requests
+import simplejson as json
 
 from worker.data.api import API
 from worker.data.enums import PartialRerunStatus
@@ -232,6 +233,6 @@ class MergingProgress:
         Sends the updated merging progress to the API.
         """
         url_path = self.get_url_path()
-        body = self.to_dict()
+        body = json.dumps(self.to_dict())
         response = self.api.patch(url_path, data=body)
         return response.response
