@@ -14,23 +14,28 @@ class Ann(Element):
     This class is extended to create annulus segment
     It can be done by passing arguments or pipe and hole section
     """
-    SERIALIZED_VARIABLES = {
-        'top_depth': float,
-        'bottom_depth': float,
-        'length': float,
 
-        'inner_diameter_hole': float,
-        'outer_diameter_pipe': float,
-        'outer_diameter_tooljoint': float,
-        'tool_joint_length_ratio': float,
-        'hole_type': HoleType
+    SERIALIZED_VARIABLES = {
+        "top_depth": float,
+        "bottom_depth": float,
+        "length": float,
+        "inner_diameter_hole": float,
+        "outer_diameter_pipe": float,
+        "outer_diameter_tooljoint": float,
+        "tool_joint_length_ratio": float,
+        "hole_type": HoleType,
     }
 
     def __init__(self, **kwargs):
         super(Ann, self).__init__(**kwargs)
 
-        for key in ['inner_diameter_hole', 'outer_diameter_pipe', 'outer_diameter_tooljoint',
-                    'tool_joint_length_ratio', 'hole_type']:
+        for key in [
+            "inner_diameter_hole",
+            "outer_diameter_pipe",
+            "outer_diameter_tooljoint",
+            "tool_joint_length_ratio",
+            "hole_type",
+        ]:
             setattr(self, key, kwargs.get(key))
 
     def set_properties_from_pipe_section(self, pipe: Pipe):
@@ -47,14 +52,14 @@ class Ann(Element):
         Compute the annulus flow area consisting of the hole section and pipe body
         :return: area in INCH^2
         """
-        return np.pi / 4 * (self.inner_diameter_hole ** 2 - self.outer_diameter_pipe ** 2)
+        return np.pi / 4 * (self.inner_diameter_hole**2 - self.outer_diameter_pipe**2)
 
     def compute_get_area_pipe_tooljoint(self) -> float:
         """
         Compute the annulus flow area consisting of the hole section and pipe tooljoint
         :return: area in INCH^2
         """
-        return np.pi / 4 * (self.inner_diameter_hole ** 2 - self.outer_diameter_tooljoint ** 2)
+        return np.pi / 4 * (self.inner_diameter_hole**2 - self.outer_diameter_tooljoint**2)
 
     # override
     def compute_get_area(self) -> float:
